==> bulmages_0.9.1.orig.tar.gz: bulmages-0.9.1/bulmages/bulmafact/src/busquedaseriefactura.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tomeu Borras Riera                              *
 *   tborras@conetxia.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef BUSQUEDASERIEFACTURA_H
#define BUSQUEDASERIEFACTURA_H

#include <QComboBox>

#include "company.h"
#include "postgresiface2.h"


/// Permite  seleccionar una serie de factura.
/** Este Widget permite buscar y seleccionar un
    n&uacute;mero de serie de factura.
    Antes de utilizarlo debe ser inicializa con setcompany.   
    Cuando se cambia el elemento seleccionado emite un SIGNAL valueChanged().
*/
class BusquedaSerieFactura : public QComboBox {
    Q_OBJECT

private:
    /// Puntero a la clase compay que permite trabajar con la Base de Datos y el paso de parametros.
    company *companyact;
    /// Este cursor almacena el listado de series de factura para poder trabajar con ellas.
    cursor2 *m_cursorcombo;
    /// Indica cual es el codigo de la serie de factura por defecto.
    QString m_codigoserie_factura;

public:
    BusquedaSerieFactura(QWidget *parent = 0);
    ~BusquedaSerieFactura();
    void setcompany(company *comp);
    virtual void setcodigoserie_factura(QString);
    QString codigoserie_factura();

public slots:
    void m_activated(int index);

signals:
    void valueChanged(QString);
};

#endif

==> bulmages_0.11.1.orig.tar.gz: bulmages-0.11.1/bulmages/bulmafact/src/busquedaseriefactura.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Tomeu Borras Riera                              *
 *   tborras@conetxia.com                                                  *
 *   http://www.iglues.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef BUSQUEDASERIEFACTURA_H
#define BUSQUEDASERIEFACTURA_H

#include "qcombobox2.h"
#include "company.h"
#include "postgresiface2.h"
#include "blwidget.h"

/// Permite  seleccionar una serie de factura.
/** Este Widget permite buscar y seleccionar un
    n&uacute;mero de serie de factura.
    Antes de utilizarlo debe ser inicializa con setcompany.
    Cuando se cambia el elemento seleccionado emite un SIGNAL valueChanged().
*/
class BusquedaSerieFactura : public QComboBox2
{
    Q_OBJECT

private:
    /// Este cursor almacena el listado de series de factura para poder trabajar con ellas.
    cursor2 *m_cursorcombo;
    /// Indica cual es el codigo de la serie de factura por defecto.
    QString m_codigoserie_factura;

public:
    BusquedaSerieFactura ( QWidget *parent = 0 );
    ~BusquedaSerieFactura();
    void setEmpresaBase ( Company *comp );
    QString codigoserie_factura();
    virtual QString valorCampo();
    virtual void setcodigoserie_factura ( QString );
    virtual void setValorCampo ( QString );

public slots:
    void m_activated ( int index );

signals:
    void valueChanged ( QString );
};

#endif
